# package-processing-Image

## Description.

Bootcamp Cognizant Cloud Data Engineer - DIO

Descrição O pacote "package-processing-image" é usado para:

Módulo "Processamento":

Correspondência de histograma; Similaridade estrutural; Redimensionar imagem;

Módulo "Utils":

Ler imagem; Salvar imagem; Plotar imagem; Resultado do gráfico; Plotar histograma;

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package-processing-Image

```bash
pip install package-processing-image
```

## Usage

```python
from processing_image.utils import io, plot
from processing_image.processing import combination, transformation
```

## Author
Marlon Martins

## License
[MIT](https://choosealicense.com/licenses/mit/)